@@ -14,10 +14,12 @@ var logger = require('winston');
 var fs = require('fs');
 var RDBStore = require('./../datasource/rethinkdb-session')(session);
 const config = require(process.cwd() + '/config/config');
-var dbId=config.appId.replace(/-/g,"");
+
 
 module.exports = function (app, db) {
     var cert = fs.readFileSync(process.cwd() + '/ssl/server.key');  // get private key
+    var dbId = config.appId.replace(/-/g, "");
+   // console.log(cert.toString());
 
     var rdbStore = new RDBStore({
         connection: db,
@@ -34,8 +36,8 @@ module.exports = function (app, db) {
         resave: false,
         saveUninitialized: true,
         key: 'sid',
-        secret: cert,
-      //  cookie: { maxAge: 5 * 60 * 1000 },
+        secret: cert.toString(),
+        //  cookie: { maxAge: 5 * 60 * 1000 },
         store: rdbStore
     }));
 
