@@ -104,7 +104,7 @@ var oauth = {
     var self = this;
     this._CallAPI("https://{OAUTH_HOST}/oauth/logout", function (data) {
       // self._deleteCookie();
-      self._setCookie("JWT", data.jwt,1);
+      self._deleteCookie("JWT");
       window.location.href = "{OAUTH_APP_LOGOUT}";
     });
 
